==> darwin-shared-0.1.14.tar.gz: darwin-shared-0.1.14/darwin/utils/error.py <==
# coding: utf-8

from ..utils.language import Language
from ..models.error import ErrorModel


def errorInvalidAccessToken(language):
    return {
        Language.portuguese: ErrorModel.new(code="invalidAccessToken", message="Acesso negado. Faça login novamente"),
        Language.english:    ErrorModel.new(code="invalidAccessToken", message="Access denied. Please sign in again"),
    }.get(language)


def errorUserTempBlocked(language, hours=3):
    return {
        Language.portuguese: ErrorModel.new(code="temporarilyBlocked", message="Seu acesso foi bloqueado por {} horas. Accesse mais tarde o sistema".format(hours)),
        Language.english:    ErrorModel.new(code="temporarilyBlocked", message="Your access has been blocked for {} hours. Try again later".format(hours))
    }.get(language)


def errorUnknownSource(language):
    return {
        Language.portuguese: ErrorModel.new(code="unknownSource", message="Rota acessada por uma fonte desconhecida"),
        Language.english:    ErrorModel.new(code="UnknownSource", message="Request's origin is an unknown source")
    }.get(language)


def errorInternalRoute(language):
    return {
        Language.portuguese: ErrorModel.new(code="privateRoute", message="Essa rota é privada ao acesso externo"),
        Language.english:    ErrorModel.new(code="privateRoute", message="This is an internal route")
    }.get(language)


def errorBreakApi(language):
    return {
        Language.portuguese: ErrorModel.new(code="internalServerError", message="Houston, temos um problema!"),
        Language.english:    ErrorModel.new(code="internalServerError", message="Houston, we have a problem!")
    }.get(language)


def errorRouteNotFound(language):
    return {
        Language.portuguese: ErrorModel.new(code="routeNotFound", message="Rota não encontrada"),
        Language.english:    ErrorModel.new(code="routeNotFound", message="Route not found")
    }.get(language)

==> darwin-shared-0.2.21.tar.gz: darwin-shared-0.2.21/darwin/utils/error.py <==
# coding: utf-8

from ..utils.language import Language
from ..models.error import ErrorModel


def errorInvalidAccessToken(language):
    return {
        Language.portuguese: ErrorModel.new(code="invalidAccessToken", message="Acesso negado. Faça login novamente"),
        Language.english:    ErrorModel.new(code="invalidAccessToken", message="Access denied. Please sign in again"),
    }.get(language)


def errorUserTempBlocked(language, hours=3):
    return {
        Language.portuguese: ErrorModel.new(code="temporarilyBlocked", message="Seu acesso foi bloqueado por {} horas. Accesse mais tarde o sistema".format(hours)),
        Language.english:    ErrorModel.new(code="temporarilyBlocked", message="Your access has been blocked for {} hours. Try again later".format(hours))
    }.get(language)


def errorUnknownSource(language):
    return {
        Language.portuguese: ErrorModel.new(code="unknownSource", message="Rota acessada por uma fonte desconhecida"),
        Language.english:    ErrorModel.new(code="unknownSource", message="Request's origin is an unknown source")
    }.get(language)


def errorInternalRoute(language):
    return {
        Language.portuguese: ErrorModel.new(code="privateRoute", message="Essa rota é privada ao acesso externo"),
        Language.english:    ErrorModel.new(code="privateRoute", message="This is an internal route")
    }.get(language)


def errorBreakApi(language):
    return {
        Language.portuguese: ErrorModel.new(code="internalServerError", message="Houston, temos um problema!"),
        Language.english:    ErrorModel.new(code="internalServerError", message="Houston, we have a problem!")
    }.get(language)


def errorRouteNotFound(language):
    return {
        Language.portuguese: ErrorModel.new(code="routeNotFound", message="Rota não encontrada"),
        Language.english:    ErrorModel.new(code="routeNotFound", message="Route not found")
    }.get(language)
